import vl from 'vega-lite-api';

const points = vl
  .markCircle({ size: 200, opacity: 1 })
  .project(vl.projection('albersUsa'))
  .encode(
    vl.longitude().fieldQ('LONGITUDE'),
    vl.latitude().fieldQ('LATITUDE'),
    vl
      .color()
      .fieldN('Track Name')
      .scale({
        domain: [
          'Atlanta Motor Speedway',
          'California Speedway',
          'Bristol Motor Speedway',
          "Lowe's Motor Speedway",
          'Chicagoland Speedway',
          'Darlington Raceway',
          'Daytona International Speedway',
          'Dover International Speedway',
          'Homestead-Miami Speedway ',
          'Indianapolis Motor Speedway',
          'Infineon Raceway',
          'Kansas Speedway',
          'Las Vegas Motor Speedway',
          'Martinsville Speedway',
          'Michigan International Speedway',
          'Nashville Speedway',
          'New Hampshire International',
          'North Wilkesboro Speedway',
          'Ontario Motor Speedway',
          'Phoenix International Raceway',
          'Pocono Raceway',
          'Richmond International Raceway',
          'Riverside International Raceway',
          'North Carolina Speedway',
          'Talladega Superspeedway',
          'Texas Motor Speedway',
          'Watkins Glen International',
        ],

        range: [
          '#b03060',
          '#8b0000',
          '#808000',
          '#00ffff',
          '#ff0000',
          '#ffa500',
          '#2e8b57',
          '#00fa9a',
          '#b03060',
          '#191970',
          '#2f4f4f',
          '#ffa500',
          '#808000',
          '#ffff00',
          '#00bfff',
          '#7cfc00',
          '#2e8b57',
          '#ff0000',
          '#f0e68c',
          '#ffa07a',
          '#ff00ff',
          '#191970',
          '#2f4f4f',
          '#8b0000',
          '#0000cd',
          '#dda0dd',
          '#7b68ee',
        ],
      }),
    vl.tooltip([
      vl.fieldN('Track Name'),
      vl.fieldN('Track Type'),
      vl.fieldN('Track Length'),
      vl.fieldN('Track Status'),
      vl.fieldN('Most Wins'),
    ])
  );
const map = vl
  .markGeoshape({
    fill: '#f0f0f0',
    stroke: '#D4D4D4',
    strokeWidth: 1,
  })
  .data(
    vl
      .topojson(
        'https://raw.githubusercontent.com/vega/vega/master/docs/data/us-10m.json'
      )
      .feature('states')
  );

export const viz = vl.layer(map, points);

