/**
import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleOrdinal,
  scaleLinear,
  scaleTime,
  max,
  format,
  timeFormat,
  tooltip,
  extent,
} from 'd3';
import ReactDropdown from 'react-dropdown';
import { useData } from './ScatterPlot/useData';
import { AxisBottom } from './ScatterPlot/AxisBottom';
import { AxisLeft } from './ScatterPlot/AxisLeft';
import { Marks } from './ScatterPlot/Marks';
import { Dropdown } from './ScatterPlot/Dropdown';
import { ColorLegend } from './ScatterPlot/ColorLegend';
*/
import { useRef, useEffect } from 'react';
export const ScatterPlot = () => {
  /**
  const width = 960;
const height = 500;
const margin = { top: 20, right: 200, bottom: 200, left: 110 };
const xAxisLabelOffset = 45;
const yAxisLabelOffset = 52;
const fadeOpacity = 0.12;

const attributes = [
  { value: 'Start', label: 'Starting Position' },
  { value: 'Payout', label: "Winner's Payout" },
  { value: 'Caution Flags', label: 'Caution Flags' },
  { value: 'Lead Changes', label: 'Lead Changes' },
  { value: 'Winning Time', label: 'Winning Time' },
];

const getLabel = (value) => {
  for (let i = 0; i < attributes.length; i++) {
    if (attributes[i].value === value) {
      return attributes[i].label;
    }
  }
};
const App = () => {
  const data = useData();
  const [hoveredValue, setHoveredValue] = useState(null);
  console.log(hoveredValue);

  const initialYAttribute = 'Start';
  const [yAttribute, setYAttribute] = useState(initialYAttribute);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xValue = (d) => d.Year;
  const xAxisLabel = "Year";
  const yValue = (d) => d[yAttribute];
  const yAxisLabel = getLabel(yAttribute)
  
  const colorValue = (d) => d['Track Name'];
  const colorLegendLabel = 'Track Name';
  
  const tooltipValue = (d) => ["Winner: " + d.Driver + "\n" + "Track Type: " + d['Track Type Short']];
  
  const filteredData = data.filter((d) => hoveredValue === colorValue(d));
  
  const circleRadius = 6;
  
  const siFormat = format('.2s');
  const xAxisTickFormat = timeFormat('%Y');
  const yAxisTickFormat = format(' ');

  const legendSize = 10;
  
  console.log(data);

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const colorScale = scaleOrdinal()
    .domain(data.map(colorValue))
  	.range(['#2f4f4f','#2e8b57','#191970','#8b0000','#808000','#b03060','#ff0000','#ffa500','#ffff00','#0000cd','#7cfc00','#00fa9a','#00ffff','#00bfff','#ff00ff','#f0e68c','#dda0dd','#7b68ee','#ffa07a','#2f4f4f','#2e8b57','#191970','#8b0000','#808000','#b03060','#ff0000','#ffa500']);  
//.range(['#e6194B','#3cb44b','#ffe119','#4363d8','#f58231','#911eb4','#42d4f4','#f032e6','#bfef45','#fabed4','#469990','#dcbeff','#9A6324','#fffac8','#800000','#aaffc3','#808000','#ffd8b1','#000075','#e6194B','#3cb44b','#ffe119','#4363d8','#f58231','#911eb4','#42d4f4','#f032e6']);

  */
  const ref = useRef();

  useEffect(() => {
    /**  
  return (
    <>
      <div className="menus-container">
		<span className="dropdown-label">Choose a Statistic: </span>
        <ReactDropdown
          options={attributes}
          id="y-select"
          value={yAttribute}
          onChange={({ value }) => setYAttribute(value)}
        />
      </div>
      <svg width={width} height={height}>
        <g transform={`translate(${margin.left},${margin.top})`}>
          <AxisBottom
            xScale={xScale}
            innerHeight={innerHeight}
            tickFormat={xAxisTickFormat}
            tickOffset={7}
          />
          <text
            className="axis-label"
            textAnchor="middle"
            transform={`translate(${-yAxisLabelOffset}, 
          ${innerHeight / 2}) rotate(-90)`}
          >
            {yAxisLabel}
          </text>
          <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={7} />
          <text
            className="axis-label"
            x={innerWidth / 2}
            y={innerHeight + xAxisLabelOffset}
            textAnchor="middle"
          >
            {xAxisLabel}
          </text>
          <g transform={`translate(${innerWidth + 40}, 5)`} font-size={legendSize}>
          <text x={35} y={-10} className="axis-label" textAnchor="middle">
            {colorLegendLabel}
          </text>
          <g>
            <ColorLegend
              tickSpacing={12}
              tickSize={10}
              tickTextOffset={9}
              tickSize={5}
              colorScale={colorScale}
              onHover={setHoveredValue}
              hoveredValue={hoveredValue}
              fadeOpacity={fadeOpacity}
            />
          </g>
          <ColorLegend
            tickSpacing={12}
            tickSize={10}
            tickTextOffset={9}
            tickSize={5}
            colorScale={colorScale}
            onHover={setHoveredValue}
          />
        </g>
        <g opacity={hoveredValue ? fadeOpacity : 5}>
          <Marks
            data={data}
            xScale={xScale}
            yScale={yScale}
            xValue={xValue}
            yValue={yValue}
            colorScale={colorScale}
            colorValue={colorValue}
            tooltipFormat={yAxisTickFormat}
            circleRadius={circleRadius}
            ttpValue={tooltipValue}
          />
        </g>
          <Marks
            data={filteredData}
            xScale={xScale}
            yScale={yScale}
            xValue={xValue}
            yValue={yValue}
            colorScale={colorScale}
          	colorValue={colorValue}
            tooltipFormat={yAxisTickFormat}
            circleRadius={circleRadius}
            ttpValue={tooltipValue}
          />
        </g>
      </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
*/
    ref.current
  }, []);

  return <div className="scatter-plot" ref={ref} />;
}